@@ -1,7 +1,7 @@
 package rjbs;
 # ABSTRACT: all the junk that rjbs likes in his one-offs
-$rjbs::VERSION = '20150423.000';
-use 5.21.10;
+$rjbs::VERSION = '20150423.001';
+use 5.20.0;
 use feature ();
 use experimental ();
 
@@ -10,10 +10,9 @@ sub import {
   strict->import;
   warnings->import;
   feature->import(':5.20');
-  experimental->import(qw(
-    signatures postderef lexical_subs
-    bitwise refaliasing
-  ));
+  experimental->import(qw( signatures postderef lexical_subs ));
+
+  $] >= 5.021010 && experimental->import(qw( bitwise refaliasing ));
 }
 
 1;
@@ -30,14 +29,14 @@ rjbs - all the junk that rjbs likes in his one-offs
 
 =head1 VERSION
 
-version 20150423.000
+version 20150423.001
 
 =head1 OVERVIEW
 
 When you C<use rjbs> you get a whole bunch of other pragmata turned on.  It
 turns on strict, warnings, all the v5.20 features, signatures, postfix
-dereferencing, lexical subs, unambiguous bitwise operators, and and reference
-aliasing.
+dereferencing, lexical subs, and if possible: unambiguous bitwise operators and
+reference aliasing.
 
 The exact behavior of this module is subject to change.  Consider it the "toy
 inside" Task::BeLike::RJBS.
